from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Counter:
	"""Counter commands group definition. 14 total commands, 2 Sub-groups, 10 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("counter", core, parent)

	@property
	def frange(self):
		"""frange commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_frange'):
			from .Counter_.Frange import Frange
			self._frange = Frange(self._core, self._base)
		return self._frange

	@property
	def use(self):
		"""use commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_use'):
			from .Counter_.Use import Use
			self._use = Use(self._core, self._base)
		return self._use

	# noinspection PyTypeChecker
	def get_detection(self) -> enums.Repeat:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:DETection \n
		Snippet: value: enums.Repeat = driver.configure.afRf.measurement.frequency.counter.get_detection() \n
		Selects whether the search procedure stops after finding an RF signal, or continues. \n
			:return: detection: SINGleshot | CONTinuous SINGleshot If the search procedure finds a signal during a search cycle, it stops after the cycle. CONTinuous The procedure continues searching until you abort the search.
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:DETection?')
		return Conversions.str_to_scalar_enum(response, enums.Repeat)

	def set_detection(self, detection: enums.Repeat) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:DETection \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.set_detection(detection = enums.Repeat.CONTinuous) \n
		Selects whether the search procedure stops after finding an RF signal, or continues. \n
			:param detection: SINGleshot | CONTinuous SINGleshot If the search procedure finds a signal during a search cycle, it stops after the cycle. CONTinuous The procedure continues searching until you abort the search.
		"""
		param = Conversions.enum_scalar_to_str(detection, enums.Repeat)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:DETection {param}')

	def get_afrequency(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:AFRequency \n
		Snippet: value: float = driver.configure.afRf.measurement.frequency.counter.get_afrequency() \n
		Specifies the single-tone audio frequency. Only relevant for SSB. \n
			:return: audio: Range: 1 Hz to 10500 Hz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:AFRequency?')
		return Conversions.str_to_float(response)

	def set_afrequency(self, audio: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:AFRequency \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.set_afrequency(audio = 1.0) \n
		Specifies the single-tone audio frequency. Only relevant for SSB. \n
			:param audio: Range: 1 Hz to 10500 Hz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(audio)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:AFRequency {param}')

	# noinspection PyTypeChecker
	def get_gcoupling(self) -> enums.GeneratorCoupling:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:GCOupling \n
		Snippet: value: enums.GeneratorCoupling = driver.configure.afRf.measurement.frequency.counter.get_gcoupling() \n
		Couples the single-tone audio frequency to an internal signal generator. Only relevant for SSB. \n
			:return: coupling: OFF | GEN1 | GEN2 | GEN3 | GEN4 OFF No coupling GENn Coupled to audio generator n
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:GCOupling?')
		return Conversions.str_to_scalar_enum(response, enums.GeneratorCoupling)

	def set_gcoupling(self, coupling: enums.GeneratorCoupling) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:GCOupling \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.set_gcoupling(coupling = enums.GeneratorCoupling.GEN1) \n
		Couples the single-tone audio frequency to an internal signal generator. Only relevant for SSB. \n
			:param coupling: OFF | GEN1 | GEN2 | GEN3 | GEN4 OFF No coupling GENn Coupled to audio generator n
		"""
		param = Conversions.enum_scalar_to_str(coupling, enums.GeneratorCoupling)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:GCOupling {param}')

	# noinspection PyTypeChecker
	def get_repetition(self) -> enums.Repeat:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:REPetition \n
		Snippet: value: enums.Repeat = driver.configure.afRf.measurement.frequency.counter.get_repetition() \n
		No command help available \n
			:return: repetition_mode: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:REPetition?')
		return Conversions.str_to_scalar_enum(response, enums.Repeat)

	def set_repetition(self, repetition_mode: enums.Repeat) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:REPetition \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.set_repetition(repetition_mode = enums.Repeat.CONTinuous) \n
		No command help available \n
			:param repetition_mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(repetition_mode, enums.Repeat)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:REPetition {param}')

	def get_timeout(self) -> int:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:TOUT \n
		Snippet: value: int = driver.configure.afRf.measurement.frequency.counter.get_timeout() \n
		Specifies a timeout for the search procedure. \n
			:return: timeout: Range: 0 s to 36E+3 s, Unit: s
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:TOUT?')
		return Conversions.str_to_int(response)

	def set_timeout(self, timeout: int) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:TOUT \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.set_timeout(timeout = 1) \n
		Specifies a timeout for the search procedure. \n
			:param timeout: Range: 0 s to 36E+3 s, Unit: s
		"""
		param = Conversions.decimal_value_to_str(timeout)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:TOUT {param}')

	def get_spower(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:SPOWer \n
		Snippet: value: float = driver.configure.afRf.measurement.frequency.counter.get_spower() \n
		No command help available \n
			:return: search_power: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:SPOWer?')
		return Conversions.str_to_float(response)

	def set_spower(self, search_power: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:SPOWer \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.set_spower(search_power = 1.0) \n
		No command help available \n
			:param search_power: No help available
		"""
		param = Conversions.decimal_value_to_str(search_power)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:SPOWer {param}')

	def get_automatic(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:AUTomatic \n
		Snippet: value: bool = driver.configure.afRf.measurement.frequency.counter.get_automatic() \n
		Selects whether search results found in 'SingleShot' mode are applied automatically or not. \n
			:return: auto: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:AUTomatic?')
		return Conversions.str_to_bool(response)

	def set_automatic(self, auto: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:AUTomatic \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.set_automatic(auto = False) \n
		Selects whether search results found in 'SingleShot' mode are applied automatically or not. \n
			:param auto: OFF | ON
		"""
		param = Conversions.bool_to_str(auto)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:AUTomatic {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.AnalogDigital:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:MODE \n
		Snippet: value: enums.AnalogDigital = driver.configure.afRf.measurement.frequency.counter.get_mode() \n
		Selects, whether the search procedure is used in 'Analog' or 'Digital' scenarios. \n
			:return: mode: ANALog | DIGital
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AnalogDigital)

	def set_mode(self, mode: enums.AnalogDigital) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:MODE \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.set_mode(mode = enums.AnalogDigital.ANALog) \n
		Selects, whether the search procedure is used in 'Analog' or 'Digital' scenarios. \n
			:param mode: ANALog | DIGital
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AnalogDigital)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:MODE {param}')

	def get_fe_power(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FEPower \n
		Snippet: value: bool = driver.configure.afRf.measurement.frequency.counter.get_fe_power() \n
		Fixes the 'Expected Power' for the search procedure. \n
			:return: state: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FEPower?')
		return Conversions.str_to_bool(response)

	def set_fe_power(self, state: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FEPower \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.set_fe_power(state = False) \n
		Fixes the 'Expected Power' for the search procedure. \n
			:param state: OFF | ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:FEPower {param}')

	def get_burst(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:BURSt \n
		Snippet: value: bool = driver.configure.afRf.measurement.frequency.counter.get_burst() \n
		No command help available \n
			:return: state: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:BURSt?')
		return Conversions.str_to_bool(response)

	def set_burst(self, state: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:BURSt \n
		Snippet: driver.configure.afRf.measurement.frequency.counter.set_burst(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:FREQuency:COUNter:BURSt {param}')

	def clone(self) -> 'Counter':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Counter(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Obw:
	"""Obw commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("obw", core, parent)

	def get_percentage(self) -> float:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:OBW:PERCentage \n
		Snippet: value: float = driver.configure.gprfMeasurement.acp.obw.get_percentage() \n
		Defines the power percentage to be used for calculation of the OBW results. \n
			:return: obw_percentage: Range: 700 ppm to 999 ppm, Unit: ppm
		"""
		response = self._core.io.query_str('CONFigure:GPRF:MEASurement<Instance>:ACP:OBW:PERCentage?')
		return Conversions.str_to_float(response)

	def set_percentage(self, obw_percentage: float) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:ACP:OBW:PERCentage \n
		Snippet: driver.configure.gprfMeasurement.acp.obw.set_percentage(obw_percentage = 1.0) \n
		Defines the power percentage to be used for calculation of the OBW results. \n
			:param obw_percentage: Range: 700 ppm to 999 ppm, Unit: ppm
		"""
		param = Conversions.decimal_value_to_str(obw_percentage)
		self._core.io.write(f'CONFigure:GPRF:MEASurement<Instance>:ACP:OBW:PERCentage {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Name:
	"""Name commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("name", core, parent)

	def set(self, bs_file_path: str, instrument=repcap.Instrument.Default) -> None:
		"""SCPI: TRACe:REMote:MODE:FILE<instrument>:NAME \n
		Snippet: driver.trace.remote.mode.file.name.set(bs_file_path = '1', instrument = repcap.Instrument.Default) \n
		Specifies path and name of the target file for tracing of the remote control interface. If you specify a new target file
		while tracing, the old target file is closed, the new file is created and tracing is continued with the new file. \n
			:param bs_file_path: String parameter specifying path and name of the file Default value: 'D:/Rohde-Schwarz/CMA/Log/version/RemoteTrace-Inst0.xml'
			:param instrument: optional repeated capability selector. Default value: Nr1 (settable in the interface 'File')"""
		param = Conversions.value_to_quoted_str(bs_file_path)
		instrument_cmd_val = self._base.get_repcap_cmd_value(instrument, repcap.Instrument)
		self._core.io.write(f'TRACe:REMote:MODE:FILE{instrument_cmd_val}:NAME {param}')

	def get(self, instrument=repcap.Instrument.Default) -> str:
		"""SCPI: TRACe:REMote:MODE:FILE<instrument>:NAME \n
		Snippet: value: str = driver.trace.remote.mode.file.name.get(instrument = repcap.Instrument.Default) \n
		Specifies path and name of the target file for tracing of the remote control interface. If you specify a new target file
		while tracing, the old target file is closed, the new file is created and tracing is continued with the new file. \n
			:param instrument: optional repeated capability selector. Default value: Nr1 (settable in the interface 'File')
			:return: bs_file_path: No help available"""
		instrument_cmd_val = self._base.get_repcap_cmd_value(instrument, repcap.Instrument)
		response = self._core.io.query_str(f'TRACe:REMote:MODE:FILE{instrument_cmd_val}:NAME?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Info:
	"""Info commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("info", core, parent)

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Usage: enums.BatteryUsage: NAV | REMovable | USED NAV Slot empty REMovable Battery inserted but currently not used - can be removed USED Battery currently used - do not remove it
			- Capacity: float: Battery capacity Unit: %
			- Design_Cap: float: Nominal capacity stated by the battery manufacturer Unit: Wh
			- Full_Ch_Cap: float: Full-charge capacity of the battery Unit: Wh
			- Voltage: float: Battery voltage Unit: V
			- Temp: float: Battery temperature Unit: °C
			- Disch_Rate: float: Discharge rate Unit: W
			- Cycle_Count: int: Charge/discharge cycles
			- Dev_Name: str: Battery name as string
			- Serial_Nr: str: Battery serial number as string
			- Manufacturer_Name: str: Battery manufacturer as string
			- Manufacture_Date: str: Battery manufacturing date as string"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Usage', enums.BatteryUsage),
			ArgStruct.scalar_float('Capacity'),
			ArgStruct.scalar_float('Design_Cap'),
			ArgStruct.scalar_float('Full_Ch_Cap'),
			ArgStruct.scalar_float('Voltage'),
			ArgStruct.scalar_float('Temp'),
			ArgStruct.scalar_float('Disch_Rate'),
			ArgStruct.scalar_int('Cycle_Count'),
			ArgStruct.scalar_str('Dev_Name'),
			ArgStruct.scalar_str('Serial_Nr'),
			ArgStruct.scalar_str('Manufacturer_Name'),
			ArgStruct.scalar_str('Manufacture_Date')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Usage: enums.BatteryUsage = None
			self.Capacity: float = None
			self.Design_Cap: float = None
			self.Full_Ch_Cap: float = None
			self.Voltage: float = None
			self.Temp: float = None
			self.Disch_Rate: float = None
			self.Cycle_Count: int = None
			self.Dev_Name: str = None
			self.Serial_Nr: str = None
			self.Manufacturer_Name: str = None
			self.Manufacture_Date: str = None

	def get(self, battery=repcap.Battery.Default) -> GetStruct:
		"""SCPI: SENSe:BASE:BATTery<BattIdx>:INFO \n
		Snippet: value: GetStruct = driver.sense.base.battery.info.get(battery = repcap.Battery.Default) \n
		Queries information for a battery slot. \n
			:param battery: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Battery')
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		battery_cmd_val = self._base.get_repcap_cmd_value(battery, repcap.Battery)
		return self._core.io.query_struct(f'SENSe:BASE:BATTery{battery_cmd_val}:INFO?', self.__class__.GetStruct())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Interferer:
	"""Interferer commands group definition. 9 total commands, 3 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("interferer", core, parent)

	@property
	def rf(self):
		"""rf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rf'):
			from .Interferer_.Rf import Rf
			self._rf = Rf(self._core, self._base)
		return self._rf

	@property
	def modulator(self):
		"""modulator commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_modulator'):
			from .Interferer_.Modulator import Modulator
			self._modulator = Modulator(self._core, self._base)
		return self._modulator

	@property
	def af(self):
		"""af commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_af'):
			from .Interferer_.Af import Af
			self._af = Af(self._core, self._base)
		return self._af

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.InterfererMode:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:MODE \n
		Snippet: value: enums.InterfererMode = driver.source.afRf.generator.interferer.get_mode() \n
		Selects the interferer signal mode. The interferer signal can be an unmodulated CW signal or a modulated signal, carrying
		a single tone. \n
			:return: interferer_mode: NONE | CW | FM | PM | AM NONE Interferer signal disabled CW Unmodulated RF carrier signal FM, PM, AM Frequency / phase / amplitude modulation
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:IFERer:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.InterfererMode)

	def set_mode(self, interferer_mode: enums.InterfererMode) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:MODE \n
		Snippet: driver.source.afRf.generator.interferer.set_mode(interferer_mode = enums.InterfererMode.AM) \n
		Selects the interferer signal mode. The interferer signal can be an unmodulated CW signal or a modulated signal, carrying
		a single tone. \n
			:param interferer_mode: NONE | CW | FM | PM | AM NONE Interferer signal disabled CW Unmodulated RF carrier signal FM, PM, AM Frequency / phase / amplitude modulation
		"""
		param = Conversions.enum_scalar_to_str(interferer_mode, enums.InterfererMode)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IFERer:MODE {param}')

	def get_dfrequency(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:DFRequency \n
		Snippet: value: float = driver.source.afRf.generator.interferer.get_dfrequency() \n
		Specifies the center RF carrier frequency of the interferer. The frequency is specified as offset value relative to the
		center carrier frequency of the wanted signal, configured via method RsCma.Source.AfRf.Generator.RfSettings.frequency. \n
			:return: frequency: Range: -10 MHz to 10 MHz, Unit: Hz
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:IFERer:DFRequency?')
		return Conversions.str_to_float(response)

	def set_dfrequency(self, frequency: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:DFRequency \n
		Snippet: driver.source.afRf.generator.interferer.set_dfrequency(frequency = 1.0) \n
		Specifies the center RF carrier frequency of the interferer. The frequency is specified as offset value relative to the
		center carrier frequency of the wanted signal, configured via method RsCma.Source.AfRf.Generator.RfSettings.frequency. \n
			:param frequency: Range: -10 MHz to 10 MHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IFERer:DFRequency {param}')

	def get_dlevel(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:DLEVel \n
		Snippet: value: float = driver.source.afRf.generator.interferer.get_dlevel() \n
		Sets the RMS level of the interferer RF signal. The level is specified as offset value relative to the level of the
		wanted signal, configured via method RsCma.Source.AfRf.Generator.RfSettings.level. \n
			:return: level: Range: -80 dB to 80 dB, Unit: dB
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:IFERer:DLEVel?')
		return Conversions.str_to_float(response)

	def set_dlevel(self, level: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IFERer:DLEVel \n
		Snippet: driver.source.afRf.generator.interferer.set_dlevel(level = 1.0) \n
		Sets the RMS level of the interferer RF signal. The level is specified as offset value relative to the level of the
		wanted signal, configured via method RsCma.Source.AfRf.Generator.RfSettings.level. \n
			:param level: Range: -80 dB to 80 dB, Unit: dB
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IFERer:DLEVel {param}')

	def clone(self) -> 'Interferer':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Interferer(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SignalQuality:
	"""SignalQuality commands group definition. 72 total commands, 6 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("signalQuality", core, parent)

	@property
	def demodLeft(self):
		"""demodLeft commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_demodLeft'):
			from .SignalQuality_.DemodLeft import DemodLeft
			self._demodLeft = DemodLeft(self._core, self._base)
		return self._demodLeft

	@property
	def demodRight(self):
		"""demodRight commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_demodRight'):
			from .SignalQuality_.DemodRight import DemodRight
			self._demodRight = DemodRight(self._core, self._base)
		return self._demodRight

	@property
	def audioInput(self):
		"""audioInput commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_audioInput'):
			from .SignalQuality_.AudioInput import AudioInput
			self._audioInput = AudioInput(self._core, self._base)
		return self._audioInput

	@property
	def spdifLeft(self):
		"""spdifLeft commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_spdifLeft'):
			from .SignalQuality_.SpdifLeft import SpdifLeft
			self._spdifLeft = SpdifLeft(self._core, self._base)
		return self._spdifLeft

	@property
	def spdifRight(self):
		"""spdifRight commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_spdifRight'):
			from .SignalQuality_.SpdifRight import SpdifRight
			self._spdifRight = SpdifRight(self._core, self._base)
		return self._spdifRight

	@property
	def voip(self):
		"""voip commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_voip'):
			from .SignalQuality_.Voip import Voip
			self._voip = Voip(self._core, self._base)
		return self._voip

	def clone(self) -> 'SignalQuality':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SignalQuality(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class File:
	"""File commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("file", core, parent)

	def get_date(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:FILE:DATE \n
		Snippet: value: str = driver.source.afRf.generator.arb.file.get_date() \n
		Queries the date and time of the loaded ARB file. \n
			:return: date: String with date and time
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ARB:FILE:DATE?')
		return trim_str_response(response)

	def get_option(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:FILE:OPTion \n
		Snippet: value: str = driver.source.afRf.generator.arb.file.get_option() \n
		Queries the options that are required to process the loaded ARB file. \n
			:return: options: String with comma-separated list of options
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ARB:FILE:OPTion?')
		return trim_str_response(response)

	def get_version(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:FILE:VERSion \n
		Snippet: value: str = driver.source.afRf.generator.arb.file.get_version() \n
		Queries the version of the loaded ARB file. \n
			:return: version: String containing the version Empty string, if no file version is defined
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ARB:FILE:VERSion?')
		return trim_str_response(response)

	def get_value(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:FILE \n
		Snippet: value: str = driver.source.afRf.generator.arb.file.get_value() \n
		Selects the ARB file to be processed. Specify the path and the filename. If the file is stored in the folder
		corresponding to the @waveform alias, it is sufficient to specify only the filename.
			INTRO_CMD_HELP: Example, the following strings are equivalent: \n
			- 'D:/Rohde-Schwarz/CMA/Data/waveform/myfile.wv'
			- '@WAVEFORM/myfile.wv'
			- 'myfile.wv' \n
			:return: arb_file: String specifying the ARB file
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:ARB:FILE?')
		return trim_str_response(response)

	def set_value(self, arb_file: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:ARB:FILE \n
		Snippet: driver.source.afRf.generator.arb.file.set_value(arb_file = '1') \n
		Selects the ARB file to be processed. Specify the path and the filename. If the file is stored in the folder
		corresponding to the @waveform alias, it is sufficient to specify only the filename.
			INTRO_CMD_HELP: Example, the following strings are equivalent: \n
			- 'D:/Rohde-Schwarz/CMA/Data/waveform/myfile.wv'
			- '@WAVEFORM/myfile.wv'
			- 'myfile.wv' \n
			:param arb_file: String specifying the ARB file
		"""
		param = Conversions.value_to_quoted_str(arb_file)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:ARB:FILE {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Update:
	"""Update commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("update", core, parent)

	def set(self, tTL=repcap.TTL.Default) -> None:
		"""SCPI: CONFigure:BASE:TTL<Index>:UPDate \n
		Snippet: driver.configure.base.ttl.update.set(tTL = repcap.TTL.Default) \n
		If TTL2 is used in input direction, this command triggers the evaluation of the input signal and a refresh of the
		resulting bit values. \n
			:param tTL: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Ttl')"""
		tTL_cmd_val = self._base.get_repcap_cmd_value(tTL, repcap.TTL)
		self._core.io.write(f'CONFigure:BASE:TTL{tTL_cmd_val}:UPDate')

	def set_with_opc(self, tTL=repcap.TTL.Default) -> None:
		tTL_cmd_val = self._base.get_repcap_cmd_value(tTL, repcap.TTL)
		"""SCPI: CONFigure:BASE:TTL<Index>:UPDate \n
		Snippet: driver.configure.base.ttl.update.set_with_opc(tTL = repcap.TTL.Default) \n
		If TTL2 is used in input direction, this command triggers the evaluation of the input signal and a refresh of the
		resulting bit values. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsCma.utilities.opc_timeout_set() to set the timeout value. \n
			:param tTL: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Ttl')"""
		self._core.io.write_with_opc(f'CONFigure:BASE:TTL{tTL_cmd_val}:UPDate')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Base:
	"""Base commands group definition. 25 total commands, 10 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("base", core, parent)

	@property
	def reference(self):
		"""reference commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_reference'):
			from .Base_.Reference import Reference
			self._reference = Reference(self._core, self._base)
		return self._reference

	@property
	def gotsystem(self):
		"""gotsystem commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_gotsystem'):
			from .Base_.Gotsystem import Gotsystem
			self._gotsystem = Gotsystem(self._core, self._base)
		return self._gotsystem

	@property
	def finish(self):
		"""finish commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_finish'):
			from .Base_.Finish import Finish
			self._finish = Finish(self._core, self._base)
		return self._finish

	@property
	def shutdown(self):
		"""shutdown commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_shutdown'):
			from .Base_.Shutdown import Shutdown
			self._shutdown = Shutdown(self._core, self._base)
		return self._shutdown

	@property
	def restart(self):
		"""restart commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_restart'):
			from .Base_.Restart import Restart
			self._restart = Restart(self._core, self._base)
		return self._restart

	@property
	def device(self):
		"""device commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_device'):
			from .Base_.Device import Device
			self._device = Device(self._core, self._base)
		return self._device

	@property
	def time(self):
		"""time commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_time'):
			from .Base_.Time import Time
			self._time = Time(self._core, self._base)
		return self._time

	@property
	def option(self):
		"""option commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_option'):
			from .Base_.Option import Option
			self._option = Option(self._core, self._base)
		return self._option

	@property
	def password(self):
		"""password commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_password'):
			from .Base_.Password import Password
			self._password = Password(self._core, self._base)
		return self._password

	@property
	def display(self):
		"""display commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_display'):
			from .Base_.Display import Display
			self._display = Display(self._core, self._base)
		return self._display

	def get_reliability(self) -> int:
		"""SCPI: SYSTem:BASE:RELiability \n
		Snippet: value: int = driver.system.base.get_reliability() \n
		Returns a reliability value, indicating errors detected by the base software. \n
			:return: value: See 'Reliability Indicator'
		"""
		response = self._core.io.query_str('SYSTem:BASE:RELiability?')
		return Conversions.str_to_int(response)

	def get_did(self) -> str:
		"""SCPI: SYSTem:BASE:DID \n
		Snippet: value: str = driver.system.base.get_did() \n
		No command help available \n
			:return: device_id: No help available
		"""
		response = self._core.io.query_str('SYSTem:BASE:DID?')
		return trim_str_response(response)

	# noinspection PyTypeChecker
	class DateStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Year: int: No parameter help available
			- Month: int: No parameter help available
			- Day: int: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Year'),
			ArgStruct.scalar_int('Month'),
			ArgStruct.scalar_int('Day')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Year: int = None
			self.Month: int = None
			self.Day: int = None

	def get_date(self) -> DateStruct:
		"""SCPI: SYSTem:BASE:DATE \n
		Snippet: value: DateStruct = driver.system.base.get_date() \n
		No command help available \n
			:return: structure: for return value, see the help for DateStruct structure arguments.
		"""
		return self._core.io.query_struct('SYSTem:BASE:DATE?', self.__class__.DateStruct())

	def set_date(self, value: DateStruct) -> None:
		"""SCPI: SYSTem:BASE:DATE \n
		Snippet: driver.system.base.set_date(value = DateStruct()) \n
		No command help available \n
			:param value: see the help for DateStruct structure arguments.
		"""
		self._core.io.write_struct('SYSTem:BASE:DATE', value)

	def get_klock(self) -> bool:
		"""SCPI: SYSTem:BASE:KLOCk \n
		Snippet: value: bool = driver.system.base.get_klock() \n
		No command help available \n
			:return: klock: No help available
		"""
		response = self._core.io.query_str('SYSTem:BASE:KLOCk?')
		return Conversions.str_to_bool(response)

	def set_klock(self, klock: bool) -> None:
		"""SCPI: SYSTem:BASE:KLOCk \n
		Snippet: driver.system.base.set_klock(klock = False) \n
		No command help available \n
			:param klock: No help available
		"""
		param = Conversions.bool_to_str(klock)
		self._core.io.write(f'SYSTem:BASE:KLOCk {param}')

	def get_version(self) -> float:
		"""SCPI: SYSTem:BASE:VERSion \n
		Snippet: value: float = driver.system.base.get_version() \n
		No command help available \n
			:return: version: No help available
		"""
		response = self._core.io.query_str('SYSTem:BASE:VERSion?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Base':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Base(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ptt:
	"""Ptt commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ptt", core, parent)

	def get_state(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:PTT:STATe \n
		Snippet: value: bool = driver.source.afRf.generator.voip.ptt.get_state() \n
		Sets the DUT's PTT state. Disable PTT at the DUT side, if you are finished with the TX testing. \n
			:return: ptt_state: OFF | ON
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:PTT:STATe?')
		return Conversions.str_to_bool(response)

	def get_value(self) -> bool:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:PTT \n
		Snippet: value: bool = driver.source.afRf.generator.voip.ptt.get_value() \n
		No command help available \n
			:return: ptt: No help available
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:VOIP:PTT?')
		return Conversions.str_to_bool(response)

	def set_value(self, ptt: bool) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:VOIP:PTT \n
		Snippet: driver.source.afRf.generator.voip.ptt.set_value(ptt = False) \n
		No command help available \n
			:param ptt: No help available
		"""
		param = Conversions.bool_to_str(ptt)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:VOIP:PTT {param}')



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Demodulation:
	"""Demodulation commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("demodulation", core, parent)

	# noinspection PyTypeChecker
	def get_xdivision(self) -> enums.Xdivision:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:XDIVision \n
		Snippet: value: enums.Xdivision = driver.configure.afRf.measurement.multiEval.oscilloscope.demodulation.get_xdivision() \n
		No command help available \n
			:return: xdivision: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:XDIVision?')
		return Conversions.str_to_scalar_enum(response, enums.Xdivision)

	def set_xdivision(self, xdivision: enums.Xdivision) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:XDIVision \n
		Snippet: driver.configure.afRf.measurement.multiEval.oscilloscope.demodulation.set_xdivision(xdivision = enums.Xdivision.M1) \n
		No command help available \n
			:param xdivision: No help available
		"""
		param = Conversions.enum_scalar_to_str(xdivision, enums.Xdivision)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:XDIVision {param}')

	def get_mtime(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:MTIMe \n
		Snippet: value: float = driver.configure.afRf.measurement.multiEval.oscilloscope.demodulation.get_mtime() \n
		No command help available \n
			:return: meas_time: No help available
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:MTIMe?')
		return Conversions.str_to_float(response)

	def set_mtime(self, meas_time: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:MTIMe \n
		Snippet: driver.configure.afRf.measurement.multiEval.oscilloscope.demodulation.set_mtime(meas_time = 1.0) \n
		No command help available \n
			:param meas_time: No help available
		"""
		param = Conversions.decimal_value_to_str(meas_time)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:MEValuation:OSCilloscope:DEModulation:MTIMe {param}')



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bin:
	"""Bin commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("bin", core, parent)

	def read(self) -> List[float]:
		"""SCPI: READ:GPRF:MEASurement<Instance>:IQRecorder:BIN \n
		Snippet: value: List[float] = driver.gprfMeasurement.iqRecorder.bin.read() \n
		Retrieve the I/Q recorder results in binary format. \n
			:return: iq_samples: Binary block data, see 'ASCII and Binary Data Formats'"""
		response = self._core.io.query_bin_or_ascii_float_list(f'READ:GPRF:MEASurement<Instance>:IQRecorder:BIN?')
		return response

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:IQRecorder:BIN \n
		Snippet: value: List[float] = driver.gprfMeasurement.iqRecorder.bin.fetch() \n
		Retrieve the I/Q recorder results in binary format. \n
			:return: iq_samples: Binary block data, see 'ASCII and Binary Data Formats'"""
		response = self._core.io.query_bin_or_ascii_float_list(f'FETCh:GPRF:MEASurement<Instance>:IQRecorder:BIN?')
		return response



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Base:
	"""Base commands group definition. 28 total commands, 11 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("base", core, parent)

	@property
	def sysSound(self):
		"""sysSound commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sysSound'):
			from .Base_.SysSound import SysSound
			self._sysSound = SysSound(self._core, self._base)
		return self._sysSound

	@property
	def cmaSound(self):
		"""cmaSound commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_cmaSound'):
			from .Base_.CmaSound import CmaSound
			self._cmaSound = CmaSound(self._core, self._base)
		return self._cmaSound

	@property
	def attenuation(self):
		"""attenuation commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_attenuation'):
			from .Base_.Attenuation import Attenuation
			self._attenuation = Attenuation(self._core, self._base)
		return self._attenuation

	@property
	def cprotection(self):
		"""cprotection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cprotection'):
			from .Base_.Cprotection import Cprotection
			self._cprotection = Cprotection(self._core, self._base)
		return self._cprotection

	@property
	def adjustment(self):
		"""adjustment commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_adjustment'):
			from .Base_.Adjustment import Adjustment
			self._adjustment = Adjustment(self._core, self._base)
		return self._adjustment

	@property
	def ttl(self):
		"""ttl commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_ttl'):
			from .Base_.Ttl import Ttl
			self._ttl = Ttl(self._core, self._base)
		return self._ttl

	@property
	def display(self):
		"""display commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_display'):
			from .Base_.Display import Display
			self._display = Display(self._core, self._base)
		return self._display

	@property
	def relay(self):
		"""relay commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_relay'):
			from .Base_.Relay import Relay
			self._relay = Relay(self._core, self._base)
		return self._relay

	@property
	def zbox(self):
		"""zbox commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_zbox'):
			from .Base_.Zbox import Zbox
			self._zbox = Zbox(self._core, self._base)
		return self._zbox

	@property
	def audioOutput(self):
		"""audioOutput commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_audioOutput'):
			from .Base_.AudioOutput import AudioOutput
			self._audioOutput = AudioOutput(self._core, self._base)
		return self._audioOutput

	@property
	def audioInput(self):
		"""audioInput commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_audioInput'):
			from .Base_.AudioInput import AudioInput
			self._audioInput = AudioInput(self._core, self._base)
		return self._audioInput

	def get_speaker(self) -> bool:
		"""SCPI: CONFigure:BASE:SPEaker \n
		Snippet: value: bool = driver.configure.base.get_speaker() \n
		Switches the loudspeaker / headphones on or off. \n
			:return: speaker: ON | OFF
		"""
		response = self._core.io.query_str('CONFigure:BASE:SPEaker?')
		return Conversions.str_to_bool(response)

	def set_speaker(self, speaker: bool) -> None:
		"""SCPI: CONFigure:BASE:SPEaker \n
		Snippet: driver.configure.base.set_speaker(speaker = False) \n
		Switches the loudspeaker / headphones on or off. \n
			:param speaker: ON | OFF
		"""
		param = Conversions.bool_to_str(speaker)
		self._core.io.write(f'CONFigure:BASE:SPEaker {param}')

	# noinspection PyTypeChecker
	def get_scenario(self) -> enums.BaseScenario:
		"""SCPI: CONFigure:BASE:SCENario \n
		Snippet: value: enums.BaseScenario = driver.configure.base.get_scenario() \n
		Selects the test scenario. Always select the scenario to be used before configuring and using an application. If you show
		the display during remote control (for example with the 'Hide Remote Screen' button or SYSTem:DISPlay:UPDate ON) , the
		execution of this command takes some seconds. Insert a pause into your test script after this command, to ensure that the
		change has been applied. Or query the setting until the correct new value is returned, before you continue your test
		script. \n
			:return: scenario: TXTest | RXTest | DXTest | SPECtrum | EXPert | AUDio | AVIonics | DTXTest | DRXTest | DSPectrum | DEXPert TXTest | RXTest | DXTest | SPECtrum | EXPert | AUDio | AVIonics Analog scenarios DTXTest | DRXTest | DSPectrum | DEXPert Digital scenarios NOSC Cannot be set, but is returned by a query if no scenario is active.
		"""
		response = self._core.io.query_str_with_opc('CONFigure:BASE:SCENario?')
		return Conversions.str_to_scalar_enum(response, enums.BaseScenario)

	def set_scenario(self, scenario: enums.BaseScenario) -> None:
		"""SCPI: CONFigure:BASE:SCENario \n
		Snippet: driver.configure.base.set_scenario(scenario = enums.BaseScenario.AUDio) \n
		Selects the test scenario. Always select the scenario to be used before configuring and using an application. If you show
		the display during remote control (for example with the 'Hide Remote Screen' button or SYSTem:DISPlay:UPDate ON) , the
		execution of this command takes some seconds. Insert a pause into your test script after this command, to ensure that the
		change has been applied. Or query the setting until the correct new value is returned, before you continue your test
		script. \n
			:param scenario: TXTest | RXTest | DXTest | SPECtrum | EXPert | AUDio | AVIonics | DTXTest | DRXTest | DSPectrum | DEXPert TXTest | RXTest | DXTest | SPECtrum | EXPert | AUDio | AVIonics Analog scenarios DTXTest | DRXTest | DSPectrum | DEXPert Digital scenarios NOSC Cannot be set, but is returned by a query if no scenario is active.
		"""
		param = Conversions.enum_scalar_to_str(scenario, enums.BaseScenario)
		self._core.io.write_with_opc(f'CONFigure:BASE:SCENario {param}')

	def clone(self) -> 'Base':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Base(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FirmwareUpdate:
	"""FirmwareUpdate commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("firmwareUpdate", core, parent)

	def get_versions(self) -> List[str]:
		"""SCPI: FETCh:FWUPdate:VERSions \n
		Snippet: value: List[str] = driver.firmwareUpdate.get_versions() \n
		No command help available \n
			:return: versions: No help available
		"""
		response = self._core.io.query_str('FETCh:FWUPdate:VERSions?')
		return Conversions.str_to_str_list(response)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 2 total commands, 1 Sub-groups, 1 group commands
	Repeated Capability: FrequencyLobe, default value after init: FrequencyLobe.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_frequencyLobe_get', 'repcap_frequencyLobe_set', repcap.FrequencyLobe.Nr1)

	def repcap_frequencyLobe_set(self, enum_value: repcap.FrequencyLobe) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to FrequencyLobe.Default
		Default value after init: FrequencyLobe.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_frequencyLobe_get(self) -> repcap.FrequencyLobe:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def dtone(self):
		"""dtone commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dtone'):
			from .Frequency_.Dtone import Dtone
			self._dtone = Dtone(self._core, self._base)
		return self._dtone

	def get_stone(self) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:FDIaling:FREQuency:STONe \n
		Snippet: value: List[float] = driver.source.afRf.generator.dialing.fdialing.frequency.get_stone() \n
		Assigns frequencies to the digits available for free dialing, tone type single tone. \n
			:return: tones_frequency: Comma-separated list of 16 frequencies, assigned to the digits 0, 1, ..., 9, A, ..., F Specifying fewer frequencies leaves the remaining digits unchanged. Range: 60 Hz to 4000 Hz, Unit: Hz
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SOURce:AFRF:GENerator<Instance>:DIALing:FDIaling:FREQuency:STONe?')
		return response

	def set_stone(self, tones_frequency: List[float]) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DIALing:FDIaling:FREQuency:STONe \n
		Snippet: driver.source.afRf.generator.dialing.fdialing.frequency.set_stone(tones_frequency = [1.1, 2.2, 3.3]) \n
		Assigns frequencies to the digits available for free dialing, tone type single tone. \n
			:param tones_frequency: Comma-separated list of 16 frequencies, assigned to the digits 0, 1, ..., 9, A, ..., F Specifying fewer frequencies leaves the remaining digits unchanged. Range: 60 Hz to 4000 Hz, Unit: Hz
		"""
		param = Conversions.list_to_csv_str(tones_frequency)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:DIALing:FDIaling:FREQuency:STONe {param}')

	def clone(self) -> 'Frequency':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Frequency(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 9 total commands, 3 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("data", core, parent)

	@property
	def tin(self):
		"""tin commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_tin'):
			from .Data_.Tin import Tin
			self._tin = Tin(self._core, self._base)
		return self._tin

	@property
	def bitErrorRate(self):
		"""bitErrorRate commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_bitErrorRate'):
			from .Data_.BitErrorRate import BitErrorRate
			self._bitErrorRate = BitErrorRate(self._core, self._base)
		return self._bitErrorRate

	@property
	def limit(self):
		"""limit commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_limit'):
			from .Data_.Limit import Limit
			self._limit = Limit(self._core, self._base)
		return self._limit

	def get_scount(self) -> int:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:SCOunt \n
		Snippet: value: int = driver.configure.afRf.measurement.data.get_scount() \n
		Sets the number of measurement intervals per measurement cycle. \n
			:return: statistic_count: Range: 1 to 1000
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DATA:SCOunt?')
		return Conversions.str_to_int(response)

	def set_scount(self, statistic_count: int) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DATA:SCOunt \n
		Snippet: driver.configure.afRf.measurement.data.set_scount(statistic_count = 1) \n
		Sets the number of measurement intervals per measurement cycle. \n
			:param statistic_count: Range: 1 to 1000
		"""
		param = Conversions.decimal_value_to_str(statistic_count)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DATA:SCOunt {param}')

	def clone(self) -> 'Data':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Data(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Base:
	"""Base commands group definition. 4 total commands, 0 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("base", core, parent)

	# noinspection PyTypeChecker
	class DataStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Data_Type: enums.DataFormat: ASCii | REAL | BINary | HEXadecimal | OCTal ASCii Numeric data is transferred as ASCII bytes. Floating point numbers are transferred in scientific E notation. REAL Numeric data is transferred in a definite length block as IEEE floating point numbers, see 'Block data'. BINary | HEXadecimal | OCTal Numeric data is transferred in binary, hexadecimal or octal format.
			- Data_Length: int: The meaning depends on the DataType as listed below. A zero returned by a query means that the default value is used. For ASCii Decimal places of floating point numbers. That means, number of 'b' digits in the scientific notation a.bbbbbbE+ccc. Default: 6 decimal places For REAL Length of floating point numbers in bits: 32 bits = 4 bytes, format #14... 64 bits = 8 bytes, format #18... Default: 64 bits For BINary, HEXadecimal, OCTal Minimum number of digits. If the number is longer, more digits are used. If it is shorter, leading zeros are added. Default: 0, no leading zeros"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Data_Type', enums.DataFormat),
			ArgStruct.scalar_int('Data_Length')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Data_Type: enums.DataFormat = None
			self.Data_Length: int = None

	# noinspection PyTypeChecker
	def get_data(self) -> DataStruct:
		"""SCPI: FORMat:BASE[:DATA] \n
		Snippet: value: DataStruct = driver.formatPy.base.get_data() \n
		Selects the format for numeric data transferred by the instrument, for example query results. \n
			:return: structure: for return value, see the help for DataStruct structure arguments.
		"""
		return self._core.io.query_struct('FORMat:BASE:DATA?', self.__class__.DataStruct())

	def set_data(self, value: DataStruct) -> None:
		"""SCPI: FORMat:BASE[:DATA] \n
		Snippet: driver.formatPy.base.set_data(value = DataStruct()) \n
		Selects the format for numeric data transferred by the instrument, for example query results. \n
			:param value: see the help for DataStruct structure arguments.
		"""
		self._core.io.write_struct('FORMat:BASE:DATA', value)

	# noinspection PyTypeChecker
	def get_border(self) -> enums.ByteOrder:
		"""SCPI: FORMat:BASE:BORDer \n
		Snippet: value: enums.ByteOrder = driver.formatPy.base.get_border() \n
		No command help available \n
			:return: byte_order: No help available
		"""
		response = self._core.io.query_str('FORMat:BASE:BORDer?')
		return Conversions.str_to_scalar_enum(response, enums.ByteOrder)

	def set_border(self, byte_order: enums.ByteOrder) -> None:
		"""SCPI: FORMat:BASE:BORDer \n
		Snippet: driver.formatPy.base.set_border(byte_order = enums.ByteOrder.NORMal) \n
		No command help available \n
			:param byte_order: No help available
		"""
		param = Conversions.enum_scalar_to_str(byte_order, enums.ByteOrder)
		self._core.io.write(f'FORMat:BASE:BORDer {param}')

	def get_dinterchange(self) -> bool:
		"""SCPI: FORMat:BASE:DINTerchange \n
		Snippet: value: bool = driver.formatPy.base.get_dinterchange() \n
		No command help available \n
			:return: dif_format: No help available
		"""
		response = self._core.io.query_str('FORMat:BASE:DINTerchange?')
		return Conversions.str_to_bool(response)

	def set_dinterchange(self, dif_format: bool) -> None:
		"""SCPI: FORMat:BASE:DINTerchange \n
		Snippet: driver.formatPy.base.set_dinterchange(dif_format = False) \n
		No command help available \n
			:param dif_format: No help available
		"""
		param = Conversions.bool_to_str(dif_format)
		self._core.io.write(f'FORMat:BASE:DINTerchange {param}')

	# noinspection PyTypeChecker
	def get_sregister(self) -> enums.StatRegFormat:
		"""SCPI: FORMat:BASE:SREGister \n
		Snippet: value: enums.StatRegFormat = driver.formatPy.base.get_sregister() \n
		No command help available \n
			:return: status_register_format: No help available
		"""
		response = self._core.io.query_str('FORMat:BASE:SREGister?')
		return Conversions.str_to_scalar_enum(response, enums.StatRegFormat)

	def set_sregister(self, status_register_format: enums.StatRegFormat) -> None:
		"""SCPI: FORMat:BASE:SREGister \n
		Snippet: driver.formatPy.base.set_sregister(status_register_format = enums.StatRegFormat.ASCii) \n
		No command help available \n
			:param status_register_format: No help available
		"""
		param = Conversions.enum_scalar_to_str(status_register_format, enums.StatRegFormat)
		self._core.io.write(f'FORMat:BASE:SREGister {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPy:
	"""FilterPy commands group definition. 11 total commands, 2 Sub-groups, 6 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("filterPy", core, parent)

	@property
	def bpass(self):
		"""bpass commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_bpass'):
			from .FilterPy_.Bpass import Bpass
			self._bpass = Bpass(self._core, self._base)
		return self._bpass

	@property
	def notch(self):
		"""notch commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_notch'):
			from .FilterPy_.Notch import Notch
			self._notch = Notch(self._core, self._base)
		return self._notch

	# noinspection PyTypeChecker
	def get_lpass(self) -> enums.LowpassFilterExtended:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:LPASs \n
		Snippet: value: enums.LowpassFilterExtended = driver.configure.afRf.measurement.voip.filterPy.get_lpass() \n
		Configures the lowpass filter in the VoIP input path. \n
			:return: filter_py: OFF | F255 | F3K | F3K4 | F4K | F15K OFF Filter disabled F255, F3K, F3K4, F4K, F15K Cutoff frequency 255 Hz / 3 kHz / 3.4 kHz / 4 kHz / 15 kHz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:LPASs?')
		return Conversions.str_to_scalar_enum(response, enums.LowpassFilterExtended)

	def set_lpass(self, filter_py: enums.LowpassFilterExtended) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:LPASs \n
		Snippet: driver.configure.afRf.measurement.voip.filterPy.set_lpass(filter_py = enums.LowpassFilterExtended.F15K) \n
		Configures the lowpass filter in the VoIP input path. \n
			:param filter_py: OFF | F255 | F3K | F3K4 | F4K | F15K OFF Filter disabled F255, F3K, F3K4, F4K, F15K Cutoff frequency 255 Hz / 3 kHz / 3.4 kHz / 4 kHz / 15 kHz
		"""
		param = Conversions.enum_scalar_to_str(filter_py, enums.LowpassFilterExtended)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:LPASs {param}')

	# noinspection PyTypeChecker
	def get_hpass(self) -> enums.HighpassFilterExtended:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:HPASs \n
		Snippet: value: enums.HighpassFilterExtended = driver.configure.afRf.measurement.voip.filterPy.get_hpass() \n
		Configures the highpass filter in the VoIP input path. \n
			:return: filter_py: OFF | F6 | F50 | F300 OFF Filter disabled F6, F50, F300 Cutoff frequency 6 Hz / 50 Hz / 300 Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:HPASs?')
		return Conversions.str_to_scalar_enum(response, enums.HighpassFilterExtended)

	def set_hpass(self, filter_py: enums.HighpassFilterExtended) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:HPASs \n
		Snippet: driver.configure.afRf.measurement.voip.filterPy.set_hpass(filter_py = enums.HighpassFilterExtended.F300) \n
		Configures the highpass filter in the VoIP input path. \n
			:param filter_py: OFF | F6 | F50 | F300 OFF Filter disabled F6, F50, F300 Cutoff frequency 6 Hz / 50 Hz / 300 Hz
		"""
		param = Conversions.enum_scalar_to_str(filter_py, enums.HighpassFilterExtended)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:HPASs {param}')

	# noinspection PyTypeChecker
	class DwidthStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Dwidth: enums.PwrFilterType: WIDE | NARRow Wide or narrow bandwidth
			- Relative: enums.Relative: RELative | CONStant Proportional to reference frequency or constant"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Dwidth', enums.PwrFilterType),
			ArgStruct.scalar_enum('Relative', enums.Relative)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Dwidth: enums.PwrFilterType = None
			self.Relative: enums.Relative = None

	# noinspection PyTypeChecker
	def get_dwidth(self) -> DwidthStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:DWIDth \n
		Snippet: value: DwidthStruct = driver.configure.afRf.measurement.voip.filterPy.get_dwidth() \n
		Configures the bandwidth of the distortion filter in the VoIP input path. \n
			:return: structure: for return value, see the help for DwidthStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:DWIDth?', self.__class__.DwidthStruct())

	def set_dwidth(self, value: DwidthStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:DWIDth \n
		Snippet: driver.configure.afRf.measurement.voip.filterPy.set_dwidth(value = DwidthStruct()) \n
		Configures the bandwidth of the distortion filter in the VoIP input path. \n
			:param value: see the help for DwidthStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:DWIDth', value)

	# noinspection PyTypeChecker
	def get_weighting(self) -> enums.WeightingFilter:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:WEIGhting \n
		Snippet: value: enums.WeightingFilter = driver.configure.afRf.measurement.voip.filterPy.get_weighting() \n
		Configures the weighting filter in the VoIP input path. \n
			:return: filter_py: OFF | AWEighting | CCITt | CMESsage OFF Filter disabled AWEighting A-weighting filter CCITt CCITT weighting filter CMESsage C-message weighting filter
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:WEIGhting?')
		return Conversions.str_to_scalar_enum(response, enums.WeightingFilter)

	def set_weighting(self, filter_py: enums.WeightingFilter) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:WEIGhting \n
		Snippet: driver.configure.afRf.measurement.voip.filterPy.set_weighting(filter_py = enums.WeightingFilter.AWEighting) \n
		Configures the weighting filter in the VoIP input path. \n
			:param filter_py: OFF | AWEighting | CCITt | CMESsage OFF Filter disabled AWEighting A-weighting filter CCITt CCITT weighting filter CMESsage C-message weighting filter
		"""
		param = Conversions.enum_scalar_to_str(filter_py, enums.WeightingFilter)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:WEIGhting {param}')

	def get_dfrequency(self) -> float:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:DFRequency \n
		Snippet: value: float = driver.configure.afRf.measurement.voip.filterPy.get_dfrequency() \n
		Configures the reference frequency for single-tone measurements via the VoIP input path. \n
			:return: distor_freq: Range: 1 Hz to 10.5 kHz, Unit: Hz
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:DFRequency?')
		return Conversions.str_to_float(response)

	def set_dfrequency(self, distor_freq: float) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:DFRequency \n
		Snippet: driver.configure.afRf.measurement.voip.filterPy.set_dfrequency(distor_freq = 1.0) \n
		Configures the reference frequency for single-tone measurements via the VoIP input path. \n
			:param distor_freq: Range: 1 Hz to 10.5 kHz, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(distor_freq)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:DFRequency {param}')

	def get_robust_auto(self) -> bool:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:ROBustauto \n
		Snippet: value: bool = driver.configure.afRf.measurement.voip.filterPy.get_robust_auto() \n
		Enables or disables robust automatic mode for distortion signal filtering in the VoIP input path. \n
			:return: automatic_mode: OFF | ON
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:ROBustauto?')
		return Conversions.str_to_bool(response)

	def set_robust_auto(self, automatic_mode: bool) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:ROBustauto \n
		Snippet: driver.configure.afRf.measurement.voip.filterPy.set_robust_auto(automatic_mode = False) \n
		Enables or disables robust automatic mode for distortion signal filtering in the VoIP input path. \n
			:param automatic_mode: OFF | ON
		"""
		param = Conversions.bool_to_str(automatic_mode)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:VOIP:FILTer:ROBustauto {param}')

	def clone(self) -> 'FilterPy':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FilterPy(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("enable", core, parent)

	def set(self, benable: bool, instrument=repcap.Instrument.Default) -> None:
		"""SCPI: TRACe:REMote:MODE:FILE<instrument>:ENABle \n
		Snippet: driver.trace.remote.mode.file.enable.set(benable = False, instrument = repcap.Instrument.Default) \n
		Enables or disables tracing of the remote control interface to a file. \n
			:param benable: 1 | 0 1: Tracing is enabled. 0: Tracing is disabled. Default value: 0
			:param instrument: optional repeated capability selector. Default value: Nr1 (settable in the interface 'File')"""
		param = Conversions.bool_to_str(benable)
		instrument_cmd_val = self._base.get_repcap_cmd_value(instrument, repcap.Instrument)
		self._core.io.write(f'TRACe:REMote:MODE:FILE{instrument_cmd_val}:ENABle {param}')

	def get(self, instrument=repcap.Instrument.Default) -> bool:
		"""SCPI: TRACe:REMote:MODE:FILE<instrument>:ENABle \n
		Snippet: value: bool = driver.trace.remote.mode.file.enable.get(instrument = repcap.Instrument.Default) \n
		Enables or disables tracing of the remote control interface to a file. \n
			:param instrument: optional repeated capability selector. Default value: Nr1 (settable in the interface 'File')
			:return: benable: No help available"""
		instrument_cmd_val = self._base.get_repcap_cmd_value(instrument, repcap.Instrument)
		response = self._core.io.query_str(f'TRACe:REMote:MODE:FILE{instrument_cmd_val}:ENABle?')
		return Conversions.str_to_bool(response)



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ....Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Qcomponent:
	"""Qcomponent commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("qcomponent", core, parent)

	def read(self) -> List[float]:
		"""SCPI: READ:GPRF:MEASurement<Instance>:FFTSanalyzer:Q \n
		Snippet: value: List[float] = driver.gprfMeasurement.fftSpecAn.qcomponent.read() \n
		Queries the contents of the time domain diagrams. There are separate commands for the I amplitudes and the Q amplitudes. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: qdata: Comma-separated list of normalized I or Q amplitudes The number of values equals the configured FFT length. The order of the values corresponds to the I/Q vs. time diagram, from left to right."""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:GPRF:MEASurement<Instance>:FFTSanalyzer:Q?', suppressed)
		return response

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:FFTSanalyzer:Q \n
		Snippet: value: List[float] = driver.gprfMeasurement.fftSpecAn.qcomponent.fetch() \n
		Queries the contents of the time domain diagrams. There are separate commands for the I amplitudes and the Q amplitudes. \n
		Use RsCma.reliability.last_value to read the updated reliability indicator. \n
			:return: qdata: Comma-separated list of normalized I or Q amplitudes The number of values equals the configured FFT length. The order of the values corresponds to the I/Q vs. time diagram, from left to right."""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:GPRF:MEASurement<Instance>:FFTSanalyzer:Q?', suppressed)
		return response



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.StructBase import StructBase
from .....Internal.ArgStruct import ArgStruct
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Demodulation:
	"""Demodulation commands group definition. 35 total commands, 5 Sub-groups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("demodulation", core, parent)

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Demodulation_.Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	@property
	def fmStereo(self):
		"""fmStereo commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fmStereo'):
			from .Demodulation_.FmStereo import FmStereo
			self._fmStereo = FmStereo(self._core, self._base)
		return self._fmStereo

	@property
	def modDepth(self):
		"""modDepth commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_modDepth'):
			from .Demodulation_.ModDepth import ModDepth
			self._modDepth = ModDepth(self._core, self._base)
		return self._modDepth

	@property
	def fdeviation(self):
		"""fdeviation commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_fdeviation'):
			from .Demodulation_.Fdeviation import Fdeviation
			self._fdeviation = Fdeviation(self._core, self._base)
		return self._fdeviation

	@property
	def filterPy(self):
		"""filterPy commands group. 2 Sub-classes, 8 commands."""
		if not hasattr(self, '_filterPy'):
			from .Demodulation_.FilterPy import FilterPy
			self._filterPy = FilterPy(self._core, self._base)
		return self._filterPy

	# noinspection PyTypeChecker
	class EnableStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Test_Left: bool: No parameter help available
			- Test_Right: bool: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Test_Left'),
			ArgStruct.scalar_bool('Test_Right')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Test_Left: bool = None
			self.Test_Right: bool = None

	def get_enable(self) -> EnableStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:ENABle \n
		Snippet: value: EnableStruct = driver.configure.afRf.measurement.demodulation.get_enable() \n
		No command help available \n
			:return: structure: for return value, see the help for EnableStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:ENABle?', self.__class__.EnableStruct())

	def set_enable(self, value: EnableStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:ENABle \n
		Snippet: driver.configure.afRf.measurement.demodulation.set_enable(value = EnableStruct()) \n
		No command help available \n
			:param value: see the help for EnableStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:ENABle', value)

	# noinspection PyTypeChecker
	class GcouplingStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Coupling_Left: enums.GeneratorCoupling: OFF | GEN1 | GEN2 | GEN3 | GEN4 OFF No coupling GENn Coupled to audio generator n
			- Coupling_Right: enums.GeneratorCoupling: OFF | GEN2 | GEN4"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Coupling_Left', enums.GeneratorCoupling),
			ArgStruct.scalar_enum('Coupling_Right', enums.GeneratorCoupling)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Coupling_Left: enums.GeneratorCoupling = None
			self.Coupling_Right: enums.GeneratorCoupling = None

	# noinspection PyTypeChecker
	def get_gcoupling(self) -> GcouplingStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:GCOupling \n
		Snippet: value: GcouplingStruct = driver.configure.afRf.measurement.demodulation.get_gcoupling() \n
		Couples the audio output paths of the demodulator to an internal signal generator.
			INTRO_CMD_HELP: For FM stereo, the settings configure the left and the right audio channel. Only the following combinations are allowed: \n
			- OFF, OFF
			- GEN1, GEN2
			- GEN3, GEN4
		For other modulation types, only <CouplingLeft> is relevant. <CouplingRight> has no effect. \n
			:return: structure: for return value, see the help for GcouplingStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:GCOupling?', self.__class__.GcouplingStruct())

	def set_gcoupling(self, value: GcouplingStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:GCOupling \n
		Snippet: driver.configure.afRf.measurement.demodulation.set_gcoupling(value = GcouplingStruct()) \n
		Couples the audio output paths of the demodulator to an internal signal generator.
			INTRO_CMD_HELP: For FM stereo, the settings configure the left and the right audio channel. Only the following combinations are allowed: \n
			- OFF, OFF
			- GEN1, GEN2
			- GEN3, GEN4
		For other modulation types, only <CouplingLeft> is relevant. <CouplingRight> has no effect. \n
			:param value: see the help for GcouplingStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:GCOupling', value)

	# noinspection PyTypeChecker
	class TmodeStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Tone_Mode_Left: enums.ToneMode: No parameter help available
			- Tone_Mode_Right: enums.ToneMode: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_enum('Tone_Mode_Left', enums.ToneMode),
			ArgStruct.scalar_enum('Tone_Mode_Right', enums.ToneMode)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Tone_Mode_Left: enums.ToneMode = None
			self.Tone_Mode_Right: enums.ToneMode = None

	# noinspection PyTypeChecker
	def get_tmode(self) -> TmodeStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:TMODe \n
		Snippet: value: TmodeStruct = driver.configure.afRf.measurement.demodulation.get_tmode() \n
		No command help available \n
			:return: structure: for return value, see the help for TmodeStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:TMODe?', self.__class__.TmodeStruct())

	def set_tmode(self, value: TmodeStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation:TMODe \n
		Snippet: driver.configure.afRf.measurement.demodulation.set_tmode(value = TmodeStruct()) \n
		No command help available \n
			:param value: see the help for TmodeStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:DEModulation:TMODe', value)

	# noinspection PyTypeChecker
	def get_value(self) -> enums.Demodulation:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation \n
		Snippet: value: enums.Demodulation = driver.configure.afRf.measurement.demodulation.get_value() \n
		Selects the type of demodulation to be performed. \n
			:return: demodulation: FMSTereo | FM | AM | USB | LSB | PM FMSTereo FM stereo multiplex signal FM, PM, AM Frequency / phase / amplitude modulation USB, LSB Single sideband modulation, upper / lower sideband
		"""
		response = self._core.io.query_str('CONFigure:AFRF:MEASurement<Instance>:DEModulation?')
		return Conversions.str_to_scalar_enum(response, enums.Demodulation)

	def set_value(self, demodulation: enums.Demodulation) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:DEModulation \n
		Snippet: driver.configure.afRf.measurement.demodulation.set_value(demodulation = enums.Demodulation.AM) \n
		Selects the type of demodulation to be performed. \n
			:param demodulation: FMSTereo | FM | AM | USB | LSB | PM FMSTereo FM stereo multiplex signal FM, PM, AM Frequency / phase / amplitude modulation USB, LSB Single sideband modulation, upper / lower sideband
		"""
		param = Conversions.enum_scalar_to_str(demodulation, enums.Demodulation)
		self._core.io.write(f'CONFigure:AFRF:MEASurement<Instance>:DEModulation {param}')

	def clone(self) -> 'Demodulation':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Demodulation(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rsquelch:
	"""Rsquelch commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rsquelch", core, parent)

	# noinspection PyTypeChecker
	class TsensitivityStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON
			- Lower: float: Range: -130 dBm to -106 dBm, Unit: dBm
			- Upper: float: Range: -108 dBm to -30 dBm, Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_tsensitivity(self) -> TsensitivityStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RSQuelch:TSENsitivity \n
		Snippet: value: TsensitivityStruct = driver.configure.afRf.measurement.searchRoutines.limit.rsquelch.get_tsensitivity() \n
		Enables a limit check and sets limits for the squelch off level. \n
			:return: structure: for return value, see the help for TsensitivityStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RSQuelch:TSENsitivity?', self.__class__.TsensitivityStruct())

	def set_tsensitivity(self, value: TsensitivityStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RSQuelch:TSENsitivity \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.limit.rsquelch.set_tsensitivity(value = TsensitivityStruct()) \n
		Enables a limit check and sets limits for the squelch off level. \n
			:param value: see the help for TsensitivityStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RSQuelch:TSENsitivity', value)

	# noinspection PyTypeChecker
	class ThysteresisStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON
			- Lower: float: Range: 0.1 dB to 3.0 dB, Unit: dB
			- Upper: float: Range: 1.0 dB to 10.0 dB, Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_thysteresis(self) -> ThysteresisStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RSQuelch:THYSteresis \n
		Snippet: value: ThysteresisStruct = driver.configure.afRf.measurement.searchRoutines.limit.rsquelch.get_thysteresis() \n
		Enables a limit check and sets limits for the squelch hysteresis result. \n
			:return: structure: for return value, see the help for ThysteresisStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RSQuelch:THYSteresis?', self.__class__.ThysteresisStruct())

	def set_thysteresis(self, value: ThysteresisStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RSQuelch:THYSteresis \n
		Snippet: driver.configure.afRf.measurement.searchRoutines.limit.rsquelch.set_thysteresis(value = ThysteresisStruct()) \n
		Enables a limit check and sets limits for the squelch hysteresis result. \n
			:param value: see the help for ThysteresisStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:SROutines:LIMit:RSQuelch:THYSteresis', value)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.StructBase import StructBase
from ...Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Queue:
	"""Queue commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("queue", core, parent)

	# noinspection PyTypeChecker
	class NextStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Error_Code: int: No parameter help available
			- Error_Description: str: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Error_Code'),
			ArgStruct.scalar_str('Error_Description')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Error_Code: int = None
			self.Error_Description: str = None

	def get_next(self) -> NextStruct:
		"""SCPI: STATus:QUEue[:NEXT] \n
		Snippet: value: NextStruct = driver.status.queue.get_next() \n
		No command help available \n
			:return: structure: for return value, see the help for NextStruct structure arguments.
		"""
		return self._core.io.query_struct('STATus:QUEue:NEXT?', self.__class__.NextStruct())



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Nxdn:
	"""Nxdn commands group definition. 12 total commands, 0 Sub-groups, 12 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("nxdn", core, parent)

	# noinspection PyTypeChecker
	def get_pattern(self) -> enums.NxdnPattern:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:PATTern \n
		Snippet: value: enums.NxdnPattern = driver.source.afRf.generator.nxdn.get_pattern() \n
		Selects the bit pattern to be transmitted as payload for NXDN. \n
			:return: pattern: P1031 | P1011 | SILence | PRBS9 | PRBS15
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:NXDN:PATTern?')
		return Conversions.str_to_scalar_enum(response, enums.NxdnPattern)

	def set_pattern(self, pattern: enums.NxdnPattern) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:PATTern \n
		Snippet: driver.source.afRf.generator.nxdn.set_pattern(pattern = enums.NxdnPattern.P1011) \n
		Selects the bit pattern to be transmitted as payload for NXDN. \n
			:param pattern: P1031 | P1011 | SILence | PRBS9 | PRBS15
		"""
		param = Conversions.enum_scalar_to_str(pattern, enums.NxdnPattern)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:NXDN:PATTern {param}')

	def get_svalue(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:SVALue \n
		Snippet: value: str = driver.source.afRf.generator.nxdn.get_svalue() \n
		Specifies the seed value for the PRBS generator, for NXDN. \n
			:return: svalue: Range: #H0 to #H1FF
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:NXDN:SVALue?')
		return trim_str_response(response)

	def set_svalue(self, svalue: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:SVALue \n
		Snippet: driver.source.afRf.generator.nxdn.set_svalue(svalue = r1) \n
		Specifies the seed value for the PRBS generator, for NXDN. \n
			:param svalue: Range: #H0 to #H1FF
		"""
		param = Conversions.value_to_str(svalue)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:NXDN:SVALue {param}')

	def get_ran(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:RAN \n
		Snippet: value: str = driver.source.afRf.generator.nxdn.get_ran() \n
		Configures the radio access number to be signaled to the DUT, for NXDN. \n
			:return: ran: Range: #H0 to #H3F
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:NXDN:RAN?')
		return trim_str_response(response)

	def set_ran(self, ran: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:RAN \n
		Snippet: driver.source.afRf.generator.nxdn.set_ran(ran = r1) \n
		Configures the radio access number to be signaled to the DUT, for NXDN. \n
			:param ran: Range: #H0 to #H3F
		"""
		param = Conversions.value_to_str(ran)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:NXDN:RAN {param}')

	def get_suid(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:SUID \n
		Snippet: value: str = driver.source.afRf.generator.nxdn.get_suid() \n
		Configures the sender ID to be signaled to the DUT, for NXDN. \n
			:return: suid: Range: #H0 to #HFFFF
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:NXDN:SUID?')
		return trim_str_response(response)

	def set_suid(self, suid: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:SUID \n
		Snippet: driver.source.afRf.generator.nxdn.set_suid(suid = r1) \n
		Configures the sender ID to be signaled to the DUT, for NXDN. \n
			:param suid: Range: #H0 to #HFFFF
		"""
		param = Conversions.value_to_str(suid)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:NXDN:SUID {param}')

	def get_duid(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:DUID \n
		Snippet: value: str = driver.source.afRf.generator.nxdn.get_duid() \n
		Configures the destination ID to be signaled to the DUT, for NXDN. \n
			:return: duid: Range: #H0 to #HFFFF
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:NXDN:DUID?')
		return trim_str_response(response)

	def set_duid(self, duid: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:DUID \n
		Snippet: driver.source.afRf.generator.nxdn.set_duid(duid = r1) \n
		Configures the destination ID to be signaled to the DUT, for NXDN. \n
			:param duid: Range: #H0 to #HFFFF
		"""
		param = Conversions.value_to_str(duid)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:NXDN:DUID {param}')

	# noinspection PyTypeChecker
	def get_transmission(self) -> enums.Transmission:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:TRANsmission \n
		Snippet: value: enums.Transmission = driver.source.afRf.generator.nxdn.get_transmission() \n
		Selects the transmission mode for NXDN. \n
			:return: trans: EHR4800 | EHR9600 | EFR9600 Enhanced half-rate (EHR) or full-rate (EFR) speech codec Transmission rate 4800 bps or 9600 bps
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:NXDN:TRANsmission?')
		return Conversions.str_to_scalar_enum(response, enums.Transmission)

	def set_transmission(self, trans: enums.Transmission) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:TRANsmission \n
		Snippet: driver.source.afRf.generator.nxdn.set_transmission(trans = enums.Transmission.EFR9600) \n
		Selects the transmission mode for NXDN. \n
			:param trans: EHR4800 | EHR9600 | EFR9600 Enhanced half-rate (EHR) or full-rate (EFR) speech codec Transmission rate 4800 bps or 9600 bps
		"""
		param = Conversions.enum_scalar_to_str(trans, enums.Transmission)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:NXDN:TRANsmission {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.FskMode:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:MODE \n
		Snippet: value: enums.FskMode = driver.source.afRf.generator.nxdn.get_mode() \n
		Queries the modulation type used for NXDN. \n
			:return: mode: FSK4
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:NXDN:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.FskMode)

	def get_standard_dev(self) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:SDEViation \n
		Snippet: value: List[float] = driver.source.afRf.generator.nxdn.get_standard_dev() \n
		Queries the frequency deviations used for 4FSK modulation, for NXDN. \n
			:return: sdeviation: List of four frequency deviations, for the symbols 01, 00, 10, 11. Range: -3000 Hz to 3000 Hz, Unit: Hz
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SOURce:AFRF:GENerator<Instance>:NXDN:SDEViation?')
		return response

	def get_symbol_rate(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:SRATe \n
		Snippet: value: float = driver.source.afRf.generator.nxdn.get_symbol_rate() \n
		Queries the symbol rate resulting from the configured transmission mode, for NXDN. \n
			:return: srate: Range: 0 symbol/s to 100E+6 symbol/s, Unit: symbol/s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:NXDN:SRATe?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_filter_py(self) -> enums.FilterNxDn:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:FILTer \n
		Snippet: value: enums.FilterNxDn = driver.source.afRf.generator.nxdn.get_filter_py() \n
		Queries the filter type used for pulse shaping for NXDN. \n
			:return: filter_py: RRC
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:NXDN:FILTer?')
		return Conversions.str_to_scalar_enum(response, enums.FilterNxDn)

	def get_ro_factor(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:ROFactor \n
		Snippet: value: float = driver.source.afRf.generator.nxdn.get_ro_factor() \n
		Queries the roll-off factor of the filter used for pulse shaping for NXDN. \n
			:return: ro_factor: Range: 0.2 to 0.2
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:NXDN:ROFactor?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_ilength(self) -> enums.ImpulseLength:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:NXDN:ILENgth \n
		Snippet: value: enums.ImpulseLength = driver.source.afRf.generator.nxdn.get_ilength() \n
		Queries the impulse length of the filter used for pulse shaping for NXDN. \n
			:return: impulse_length: T2
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:NXDN:ILENgth?')
		return Conversions.str_to_scalar_enum(response, enums.ImpulseLength)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ratio:
	"""Ratio commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ratio", core, parent)

	def set(self, ratio: float, standard: enums.Standard = None) -> None:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:IQRecorder:RATio \n
		Snippet: driver.configure.vse.measurement.iqRecorder.ratio.set(ratio = 1.0, standard = enums.Standard.CUSTom) \n
		Sets or queries the ratio of Sample Rate and Max. Sample Rate. \n
			:param ratio: Range: 0.1 to 1
			:param standard: DMR | NXDN | P25 | TETRa | LTE | UDEFined
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('ratio', ratio, DataType.Float), ArgSingle('standard', standard, DataType.Enum, True))
		self._core.io.write(f'CONFigure:VSE:MEASurement<Instance>:IQRecorder:RATio {param}'.rstrip())

	def get(self) -> float:
		"""SCPI: CONFigure:VSE:MEASurement<Instance>:IQRecorder:RATio \n
		Snippet: value: float = driver.configure.vse.measurement.iqRecorder.ratio.get() \n
		Sets or queries the ratio of Sample Rate and Max. Sample Rate. \n
			:return: ratio: Range: 0.1 to 1"""
		response = self._core.io.query_str(f'CONFigure:VSE:MEASurement<Instance>:IQRecorder:RATio?')
		return Conversions.str_to_float(response)



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cqpsk:
	"""Cqpsk commands group definition. 5 total commands, 0 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cqpsk", core, parent)

	# noinspection PyTypeChecker
	def get_ilength(self) -> enums.ImpulseLength:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:CQPSk:ILENgth \n
		Snippet: value: enums.ImpulseLength = driver.source.afRf.generator.ptFive.cqpsk.get_ilength() \n
		Queries the impulse length of the filter used for pulse shaping for P25 with CQPSK modulation. \n
			:return: impulse_length: T2
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:PTFive:CQPSk:ILENgth?')
		return Conversions.str_to_scalar_enum(response, enums.ImpulseLength)

	def get_standard_dev(self) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:CQPSk:SDEViation \n
		Snippet: value: List[float] = driver.source.afRf.generator.ptFive.cqpsk.get_standard_dev() \n
		Queries the phase changes used for CQPSK modulation, for P25. \n
			:return: sdeviation: List of four phase changes, for the symbols 01, 00, 10, 11. Range: -180 deg to 180 deg, Unit: deg
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SOURce:AFRF:GENerator<Instance>:PTFive:CQPSk:SDEViation?')
		return response

	def get_ro_factor(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:CQPSk:ROFactor \n
		Snippet: value: float = driver.source.afRf.generator.ptFive.cqpsk.get_ro_factor() \n
		Queries the roll-off factor of the filter used for pulse shaping for P25 with CQPSK modulation. \n
			:return: ro_factor: Range: 0.2 to 0.2
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:PTFive:CQPSk:ROFactor?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_filter_py(self) -> enums.PtFiveFilter:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:CQPSk:FILTer \n
		Snippet: value: enums.PtFiveFilter = driver.source.afRf.generator.ptFive.cqpsk.get_filter_py() \n
		Queries the filter type used for pulse shaping for P25 with CQPSK modulation. \n
			:return: filter_py: RRC
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:PTFive:CQPSk:FILTer?')
		return Conversions.str_to_scalar_enum(response, enums.PtFiveFilter)

	def get_symbol_rate(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:PTFive:CQPSk:SRATe \n
		Snippet: value: float = driver.source.afRf.generator.ptFive.cqpsk.get_symbol_rate() \n
		Queries the symbol rate for P25 with CQPSK modulation. \n
			:return: srate: Range: 4800 symbol/s to 4800 symbol/s , Unit: symbol/s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:PTFive:CQPSk:SRATe?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tmode:
	"""Tmode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tmode", core, parent)

	def set(self, tone_type: enums.ToneTypeA, internalGen=repcap.InternalGen.Default) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:TMODe \n
		Snippet: driver.source.afRf.generator.internalGenerator.tmode.set(tone_type = enums.ToneTypeA.DTMF, internalGen = repcap.InternalGen.Default) \n
		Selects the tone mode of an internal audio generator. \n
			:param tone_type: STONe | DTONe | MTONe | NOISe | DTMF | SELCall | FDIaling | SCAL | SQUare STONe Single audio tone MTONe Multitone signal NOISe Noise signal DTMF DTMF sequence SELCall SelCall selective calling FDIaling Free dialing SCAL SELCAL selective calling SQUare Square signal
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')"""
		param = Conversions.enum_scalar_to_str(tone_type, enums.ToneTypeA)
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		self._core.io.write(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:TMODe {param}')

	# noinspection PyTypeChecker
	def get(self, internalGen=repcap.InternalGen.Default) -> enums.ToneTypeA:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:IGENerator<nr>:TMODe \n
		Snippet: value: enums.ToneTypeA = driver.source.afRf.generator.internalGenerator.tmode.get(internalGen = repcap.InternalGen.Default) \n
		Selects the tone mode of an internal audio generator. \n
			:param internalGen: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InternalGenerator')
			:return: tone_type: STONe | DTONe | MTONe | NOISe | DTMF | SELCall | FDIaling | SCAL | SQUare STONe Single audio tone MTONe Multitone signal NOISe Noise signal DTMF DTMF sequence SELCall SelCall selective calling FDIaling Free dialing SCAL SELCAL selective calling SQUare Square signal"""
		internalGen_cmd_val = self._base.get_repcap_cmd_value(internalGen, repcap.InternalGen)
		response = self._core.io.query_str(f'SOURce:AFRF:GENerator<Instance>:IGENerator{internalGen_cmd_val}:TMODe?')
		return Conversions.str_to_scalar_enum(response, enums.ToneTypeA)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Limit:
	"""Limit commands group definition. 5 total commands, 0 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("limit", core, parent)

	# noinspection PyTypeChecker
	class EnableStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Power: bool: OFF | ON
			- Pep: bool: OFF | ON
			- Crest_Factor: bool: OFF | ON
			- Ccdf: bool: OFF | ON"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Power'),
			ArgStruct.scalar_bool('Pep'),
			ArgStruct.scalar_bool('Crest_Factor'),
			ArgStruct.scalar_bool('Ccdf')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Power: bool = None
			self.Pep: bool = None
			self.Crest_Factor: bool = None
			self.Ccdf: bool = None

	def get_enable(self) -> EnableStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:ENABle \n
		Snippet: value: EnableStruct = driver.configure.gprfMeasurement.nrt.forward.limit.get_enable() \n
		Enables/disables the limit check for the forward direction results. \n
			:return: structure: for return value, see the help for EnableStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:ENABle?', self.__class__.EnableStruct())

	def set_enable(self, value: EnableStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:ENABle \n
		Snippet: driver.configure.gprfMeasurement.nrt.forward.limit.set_enable(value = EnableStruct()) \n
		Enables/disables the limit check for the forward direction results. \n
			:param value: see the help for EnableStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:ENABle', value)

	# noinspection PyTypeChecker
	class PowerStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Lower: float: Range: Depends on sensor model , Unit: dBm
			- Upper: float: Range: Depends on sensor model , Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lower: float = None
			self.Upper: float = None

	def get_power(self) -> PowerStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:POWer \n
		Snippet: value: PowerStruct = driver.configure.gprfMeasurement.nrt.forward.limit.get_power() \n
		Configures limits for the forward power results. \n
			:return: structure: for return value, see the help for PowerStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:POWer?', self.__class__.PowerStruct())

	def set_power(self, value: PowerStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:POWer \n
		Snippet: driver.configure.gprfMeasurement.nrt.forward.limit.set_power(value = PowerStruct()) \n
		Configures limits for the forward power results. \n
			:param value: see the help for PowerStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:POWer', value)

	# noinspection PyTypeChecker
	class PepStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Lower: float: Range: Depends on sensor model , Unit: dBm
			- Upper: float: Range: Depends on sensor model , Unit: dBm"""
		__meta_args_list = [
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lower: float = None
			self.Upper: float = None

	def get_pep(self) -> PepStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:PEP \n
		Snippet: value: PepStruct = driver.configure.gprfMeasurement.nrt.forward.limit.get_pep() \n
		Configures limits for the PEP results. \n
			:return: structure: for return value, see the help for PepStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:PEP?', self.__class__.PepStruct())

	def set_pep(self, value: PepStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:PEP \n
		Snippet: driver.configure.gprfMeasurement.nrt.forward.limit.set_pep(value = PepStruct()) \n
		Configures limits for the PEP results. \n
			:param value: see the help for PepStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:PEP', value)

	# noinspection PyTypeChecker
	class CfactorStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Lower: float: Range: 0 dB to 50 dB, Unit: dB
			- Upper: float: Range: 0 dB to 50 dB, Unit: dB"""
		__meta_args_list = [
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lower: float = None
			self.Upper: float = None

	def get_cfactor(self) -> CfactorStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:CFACtor \n
		Snippet: value: CfactorStruct = driver.configure.gprfMeasurement.nrt.forward.limit.get_cfactor() \n
		Configures limits for the crest factor results. \n
			:return: structure: for return value, see the help for CfactorStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:CFACtor?', self.__class__.CfactorStruct())

	def set_cfactor(self, value: CfactorStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:CFACtor \n
		Snippet: driver.configure.gprfMeasurement.nrt.forward.limit.set_cfactor(value = CfactorStruct()) \n
		Configures limits for the crest factor results. \n
			:param value: see the help for CfactorStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:CFACtor', value)

	# noinspection PyTypeChecker
	class CumulativeDistribFncStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Lower: float: Range: 0 % to 100 %, Unit: %
			- Upper: float: Range: 0 % to 100 %, Unit: %"""
		__meta_args_list = [
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lower: float = None
			self.Upper: float = None

	def get_cumulative_distrib_fnc(self) -> CumulativeDistribFncStruct:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:CCDF \n
		Snippet: value: CumulativeDistribFncStruct = driver.configure.gprfMeasurement.nrt.forward.limit.get_cumulative_distrib_fnc() \n
		Configures limits for the CCDF results. \n
			:return: structure: for return value, see the help for CumulativeDistribFncStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:CCDF?', self.__class__.CumulativeDistribFncStruct())

	def set_cumulative_distrib_fnc(self, value: CumulativeDistribFncStruct) -> None:
		"""SCPI: CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:CCDF \n
		Snippet: driver.configure.gprfMeasurement.nrt.forward.limit.set_cumulative_distrib_fnc(value = CumulativeDistribFncStruct()) \n
		Configures limits for the CCDF results. \n
			:param value: see the help for CumulativeDistribFncStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:GPRF:MEASurement<Instance>:NRT:FWARd:LIMit:CCDF', value)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.StructBase import StructBase
from .........Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mdeviation:
	"""Mdeviation commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mdeviation", core, parent)

	# noinspection PyTypeChecker
	class PeakStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Lower: float: Lower multiplex deviation limit A setting configures also the upper limit (same absolute value, positive sign) . Range: -100 kHz to 0 Hz, Unit: Hz
			- Upper: float: A query returns the upper multiplex deviation limit. A setting ignores this parameter. Range: 0 Hz to 100 kHz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Lower'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Lower: float = None
			self.Upper: float = None

	def get_peak(self) -> PeakStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:MDEViation:PEAK \n
		Snippet: value: PeakStruct = driver.configure.afRf.measurement.multiEval.limit.demodulation.fmStereo.mdeviation.get_peak() \n
		Configures limits for the multiplex deviation results '+Peak' and '-Peak', measured for FM stereo. \n
			:return: structure: for return value, see the help for PeakStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:MDEViation:PEAK?', self.__class__.PeakStruct())

	def set_peak(self, value: PeakStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:MDEViation:PEAK \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.demodulation.fmStereo.mdeviation.set_peak(value = PeakStruct()) \n
		Configures limits for the multiplex deviation results '+Peak' and '-Peak', measured for FM stereo. \n
			:param value: see the help for PeakStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:MDEViation:PEAK', value)

	# noinspection PyTypeChecker
	class RmsStruct(StructBase):
		"""Structure for reading output parameters. Fields: \n
			- Enable: bool: OFF | ON Enables or disables the limit check
			- Upper: float: Upper multiplex deviation limit Range: 0 Hz to 100 kHz, Unit: Hz"""
		__meta_args_list = [
			ArgStruct.scalar_bool('Enable'),
			ArgStruct.scalar_float('Upper')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Enable: bool = None
			self.Upper: float = None

	def get_rms(self) -> RmsStruct:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:MDEViation:RMS \n
		Snippet: value: RmsStruct = driver.configure.afRf.measurement.multiEval.limit.demodulation.fmStereo.mdeviation.get_rms() \n
		Configures a limit for the 'RMS' multiplex deviation results, measured for FM stereo. \n
			:return: structure: for return value, see the help for RmsStruct structure arguments.
		"""
		return self._core.io.query_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:MDEViation:RMS?', self.__class__.RmsStruct())

	def set_rms(self, value: RmsStruct) -> None:
		"""SCPI: CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:MDEViation:RMS \n
		Snippet: driver.configure.afRf.measurement.multiEval.limit.demodulation.fmStereo.mdeviation.set_rms(value = RmsStruct()) \n
		Configures a limit for the 'RMS' multiplex deviation results, measured for FM stereo. \n
			:param value: see the help for RmsStruct structure arguments.
		"""
		self._core.io.write_struct('CONFigure:AFRF:MEASurement<Instance>:MEValuation:LIMit:DEModulation:FMSTereo:MDEViation:RMS', value)



from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dmr:
	"""Dmr commands group definition. 11 total commands, 0 Sub-groups, 11 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dmr", core, parent)

	# noinspection PyTypeChecker
	def get_pattern(self) -> enums.DmrPattern:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:PATTern \n
		Snippet: value: enums.DmrPattern = driver.source.afRf.generator.dmr.get_pattern() \n
		Selects the bit pattern to be transmitted as payload for DMR. \n
			:return: pattern: P1031 | SILence | PRBS9 | O153 | C153
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DMR:PATTern?')
		return Conversions.str_to_scalar_enum(response, enums.DmrPattern)

	def set_pattern(self, pattern: enums.DmrPattern) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:PATTern \n
		Snippet: driver.source.afRf.generator.dmr.set_pattern(pattern = enums.DmrPattern.BPRB15) \n
		Selects the bit pattern to be transmitted as payload for DMR. \n
			:param pattern: P1031 | SILence | PRBS9 | O153 | C153
		"""
		param = Conversions.enum_scalar_to_str(pattern, enums.DmrPattern)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DMR:PATTern {param}')

	def get_svalue(self) -> str:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:SVALue \n
		Snippet: value: str = driver.source.afRf.generator.dmr.get_svalue() \n
		Specifies the 9-bit seed value for the PRBS generator, for DMR. \n
			:return: svalue: Range: #H0 to #H1FF
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DMR:SVALue?')
		return trim_str_response(response)

	def set_svalue(self, svalue: str) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:SVALue \n
		Snippet: driver.source.afRf.generator.dmr.set_svalue(svalue = r1) \n
		Specifies the 9-bit seed value for the PRBS generator, for DMR. \n
			:param svalue: Range: #H0 to #H1FF
		"""
		param = Conversions.value_to_str(svalue)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DMR:SVALue {param}')

	def get_ccode(self) -> int:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:CCODe \n
		Snippet: value: int = driver.source.afRf.generator.dmr.get_ccode() \n
		Defines the color code to be signaled to the DUT, for DMR. \n
			:return: ccode: Range: 0 to 15
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DMR:CCODe?')
		return Conversions.str_to_int(response)

	def set_ccode(self, ccode: int) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:CCODe \n
		Snippet: driver.source.afRf.generator.dmr.set_ccode(ccode = 1) \n
		Defines the color code to be signaled to the DUT, for DMR. \n
			:param ccode: Range: 0 to 15
		"""
		param = Conversions.decimal_value_to_str(ccode)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DMR:CCODe {param}')

	def get_saddress(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:SADDress \n
		Snippet: value: float = driver.source.afRf.generator.dmr.get_saddress() \n
		Configures the source address to be signaled to the DUT, for DMR. \n
			:return: saddress: Range: 0 to 16777215
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DMR:SADDress?')
		return Conversions.str_to_float(response)

	def set_saddress(self, saddress: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:SADDress \n
		Snippet: driver.source.afRf.generator.dmr.set_saddress(saddress = 1.0) \n
		Configures the source address to be signaled to the DUT, for DMR. \n
			:param saddress: Range: 0 to 16777215
		"""
		param = Conversions.decimal_value_to_str(saddress)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DMR:SADDress {param}')

	def get_gaddress(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:GADDress \n
		Snippet: value: float = driver.source.afRf.generator.dmr.get_gaddress() \n
		Configures the group address to be signaled to the DUT, for DMR. \n
			:return: gaddress: Range: 0 to 16777215
		"""
		response = self._core.io.query_str_with_opc('SOURce:AFRF:GENerator<Instance>:DMR:GADDress?')
		return Conversions.str_to_float(response)

	def set_gaddress(self, gaddress: float) -> None:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:GADDress \n
		Snippet: driver.source.afRf.generator.dmr.set_gaddress(gaddress = 1.0) \n
		Configures the group address to be signaled to the DUT, for DMR. \n
			:param gaddress: Range: 0 to 16777215
		"""
		param = Conversions.decimal_value_to_str(gaddress)
		self._core.io.write_with_opc(f'SOURce:AFRF:GENerator<Instance>:DMR:GADDress {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.FskMode:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:MODE \n
		Snippet: value: enums.FskMode = driver.source.afRf.generator.dmr.get_mode() \n
		Queries the modulation type used for DMR. \n
			:return: mode: FSK4
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DMR:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.FskMode)

	def get_standard_dev(self) -> List[float]:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:SDEViation \n
		Snippet: value: List[float] = driver.source.afRf.generator.dmr.get_standard_dev() \n
		Queries the frequency deviations used for 4FSK modulation, for DMR. \n
			:return: sdeviation: List of four frequency deviations, for the symbols 01, 00, 10, 11. Range: -2000 Hz to 2000 Hz, Unit: Hz
		"""
		response = self._core.io.query_bin_or_ascii_float_list_with_opc('SOURce:AFRF:GENerator<Instance>:DMR:SDEViation?')
		return response

	def get_symbol_rate(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:SRATe \n
		Snippet: value: float = driver.source.afRf.generator.dmr.get_symbol_rate() \n
		Queries the symbol rate for DMR. \n
			:return: srate: Range: 4800 symbol/s to 4800 symbol/s , Unit: symbol/s
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DMR:SRATe?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_filter_py(self) -> enums.PulseShapingFilter:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:FILTer \n
		Snippet: value: enums.PulseShapingFilter = driver.source.afRf.generator.dmr.get_filter_py() \n
		Queries the filter type used for pulse shaping for DMR. \n
			:return: filter_py: RRC
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DMR:FILTer?')
		return Conversions.str_to_scalar_enum(response, enums.PulseShapingFilter)

	def get_ro_factor(self) -> float:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:ROFactor \n
		Snippet: value: float = driver.source.afRf.generator.dmr.get_ro_factor() \n
		Queries the roll-off factor of the filter used for pulse shaping for DMR. \n
			:return: ro_factor: Range: 0.2 to 0.2
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DMR:ROFactor?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_ilength(self) -> enums.ImpulseLength:
		"""SCPI: SOURce:AFRF:GENerator<Instance>:DMR:ILENgth \n
		Snippet: value: enums.ImpulseLength = driver.source.afRf.generator.dmr.get_ilength() \n
		Queries the impulse length of the filter used for pulse shaping for DMR. \n
			:return: impulse_length: T2
		"""
		response = self._core.io.query_str('SOURce:AFRF:GENerator<Instance>:DMR:ILENgth?')
		return Conversions.str_to_scalar_enum(response, enums.ImpulseLength)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Demodulation:
	"""Demodulation commands group definition. 35 total commands, 5 Sub-groups, 0 group commands
	Repeated Capability: Channel, default value after init: Channel.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("demodulation", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_channel_get', 'repcap_channel_set', repcap.Channel.Nr1)

	def repcap_channel_set(self, enum_value: repcap.Channel) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Channel.Default
		Default value after init: Channel.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_channel_get(self) -> repcap.Channel:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def marker(self):
		"""marker commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_marker'):
			from .Demodulation_.Marker import Marker
			self._marker = Marker(self._core, self._base)
		return self._marker

	@property
	def pdeviation(self):
		"""pdeviation commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_pdeviation'):
			from .Demodulation_.Pdeviation import Pdeviation
			self._pdeviation = Pdeviation(self._core, self._base)
		return self._pdeviation

	@property
	def modDepth(self):
		"""modDepth commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_modDepth'):
			from .Demodulation_.ModDepth import ModDepth
			self._modDepth = ModDepth(self._core, self._base)
		return self._modDepth

	@property
	def usbPower(self):
		"""usbPower commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_usbPower'):
			from .Demodulation_.UsbPower import UsbPower
			self._usbPower = UsbPower(self._core, self._base)
		return self._usbPower

	@property
	def lsbPower(self):
		"""lsbPower commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_lsbPower'):
			from .Demodulation_.LsbPower import LsbPower
			self._lsbPower = LsbPower(self._core, self._base)
		return self._lsbPower

	def clone(self) -> 'Demodulation':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Demodulation(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Generator:
	"""Generator commands group definition. 74 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("generator", core, parent)

	@property
	def rfSettings(self):
		"""rfSettings commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_rfSettings'):
			from .Generator_.RfSettings import RfSettings
			self._rfSettings = RfSettings(self._core, self._base)
		return self._rfSettings

	@property
	def vor(self):
		"""vor commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_vor'):
			from .Generator_.Vor import Vor
			self._vor = Vor(self._core, self._base)
		return self._vor

	@property
	def ils(self):
		"""ils commands group. 3 Sub-classes, 2 commands."""
		if not hasattr(self, '_ils'):
			from .Generator_.Ils import Ils
			self._ils = Ils(self._core, self._base)
		return self._ils

	@property
	def markerBeacon(self):
		"""markerBeacon commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_markerBeacon'):
			from .Generator_.MarkerBeacon import MarkerBeacon
			self._markerBeacon = MarkerBeacon(self._core, self._base)
		return self._markerBeacon

	def clone(self) -> 'Generator':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Generator(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
